@@ -7,6 +7,7 @@
 #include "Rivet/Projections/IdentifiedFinalState.hh"
 #include "Rivet/Projections/UnstableParticles.hh"
 #include "Rivet/Projections/FastJets.hh"
+#include "Rivet/Tools/Random.hh"
 
 namespace Rivet {
 
@@ -16,8 +17,7 @@ namespace Rivet {
   public:
 
     /// Constructor
-    ATLAS_2014_I1327229()
-      : Analysis("ATLAS_2014_I1327229") {    }
+    RIVET_DEFAULT_ANALYSIS_CTOR(ATLAS_2014_I1327229);
 
 
     /// Book histograms and initialise projections before the run
@@ -26,10 +26,6 @@ namespace Rivet {
       // To calculate the acceptance without having the fiducial lepton efficiencies included, this part can be turned off
       _use_fiducial_lepton_efficiency = true;
 
-      // Random numbers for simulation of ATLAS detector reconstruction efficiency
-      /// @todo Replace with SmearedParticles etc.
-      srand(160385);
-
       // Read in all signal regions
       _signal_regions = getSignalRegions();
 
@@ -50,7 +46,7 @@ namespace Rivet {
       // Final state including all AntiKt 04 Jets
       VetoedFinalState vfs;
       vfs.addVetoPairId(PID::MUON);
-      declare(FastJets(vfs, FastJets::ANTIKT, 0.4), "AntiKtJets04");
+      declare(FastJets(vfs, JetAlg::ANTIKT, 0.4), "AntiKtJets04");
 
       // Final state including all unstable particles (including taus)
       declare(UnstableParticles(Cuts::abseta < 5.0 && Cuts::pT > 5*GeV),"UFS");
@@ -115,9 +111,9 @@ namespace Rivet {
 
         // Apply reconstruction efficiency and simulate reconstruction
         int muon_id = 13;
-        if (mu.hasAncestor(PID::TAU) || mu.hasAncestor(-PID::TAU)) muon_id = 14;
+        if (mu.hasAncestorWith(Cuts::pid == PID::TAU) || mu.hasAncestorWith(Cuts::pid == -PID::TAU)) muon_id = 14;
         const double eff = (_use_fiducial_lepton_efficiency) ? apply_reco_eff(muon_id,mu) : 1.0;
-        const bool keep_muon = rand()/static_cast<double>(RAND_MAX)<=eff;
+        const bool keep_muon = rand01()<=eff;
 
         // Keep muon if pTCone30/pT < 0.15 and eTCone30/pT < 0.2 and reconstructed
         if (keep_muon && pTinCone/mu.pT() <= 0.1 && eTinCone/mu.pT() < 0.1)
@@ -145,9 +141,9 @@ namespace Rivet {
 
         // Apply reconstruction efficiency and simulate reconstruction
         int elec_id = 11;
-        if (e.hasAncestor(15) || e.hasAncestor(-15)) elec_id = 12;
+        if (e.hasAncestorWith(Cuts::pid == 15) || e.hasAncestorWith(Cuts::pid == -15)) elec_id = 12;
         const double eff = (_use_fiducial_lepton_efficiency) ? apply_reco_eff(elec_id,e) : 1.0;
-        const bool keep_elec = rand()/static_cast<double>(RAND_MAX)<=eff;
+        const bool keep_elec = rand01()<=eff;
 
         // Keep electron if pTCone30/pT < 0.13 and eTCone30/pT < 0.2 and reconstructed
         if (keep_elec && pTinCone/e.pT() <= 0.1  && eTinCone/e.pT() < 0.1)
@@ -181,17 +177,14 @@ namespace Rivet {
 
 
         const double eff = (_use_fiducial_lepton_efficiency) ? apply_reco_eff(tau_id,tau_vis) : 1.0;
-        const bool keep_tau = rand()/static_cast<double>(RAND_MAX)<=eff;
+        const bool keep_tau = rand01()<=eff;
 
         // Keep tau if nprong = 1, it decays hadronically and it is reconstructed
         if ( !lep_decaying_tau && nprong == 1 && keep_tau) tau_candidates.push_back(tau_vis);
       }
 
       // Jets (all anti-kt R=0.4 jets with pT > 30 GeV and eta < 4.9
-      Jets jet_candidates;
-      for (const Jet& jet : apply<FastJets>(event, "AntiKtJets04").jetsByPt(30.0*GeV) ) {
-        if (jet.abseta() < 4.9 ) jet_candidates.push_back(jet);
-      }
+      Jets jet_candidates = apply<FastJets>(event, "AntiKtJets04").jetsByPt(Cuts::pT > 30.0*GeV && Cuts::abseta < 4.9);
 
       // ETmiss
       Particles vfs_particles = apply<VisibleFinalState>(event, "VFS").particles();
@@ -324,7 +317,7 @@ namespace Rivet {
       // ---------------------
 
       // Jet cleaning
-      if (rand()/static_cast<double>(RAND_MAX) <= 0.42) {
+      if (rand01() <= 0.42) {
         for (const Jet& jet : recon_jets ) {
           const double eta = jet.rapidity();
           const double phi = jet.azimuthalAngle(MINUSPI_PLUSPI);
@@ -347,8 +340,8 @@ namespace Rivet {
       if (recon_mu.size() + recon_e.size() + recon_tau.size() < 3 || recon_leptons.size() < 2) vetoEvent;
 
       // Sort leptons by decreasing pT
-      sortByPt(recon_leptons);
-      sortByPt(recon_tau);
+      isortByPt(recon_leptons);
+      isortByPt(recon_tau);
 
       // Calculate HTlep, fill lepton pT histograms & store chosen combination of 3 leptons
       double HTlep = 0.;
@@ -394,8 +387,8 @@ namespace Rivet {
         }
       }
 
-      sortByPt(mT_leptons);
-      sortByPt(mTW_leptons);
+      isortByPt(mT_leptons);
+      isortByPt(mTW_leptons);
 
       double mT = sqrt(2*pTmiss.pT()/GeV*mT_leptons[0].pT()/GeV*(1-cos(pTmiss.phi()-mT_leptons[0].phi())));
       double mTW = sqrt(2*pTmiss.pT()/GeV*mTW_leptons[0].pT()/GeV*(1-cos(pTmiss.phi()-mTW_leptons[0].phi())));
@@ -552,7 +545,7 @@ namespace Rivet {
 
 
     /// Helper functions
-    //@{
+    /// @{
     /// Function giving a list of all signal regions
     vector<string> getSignalRegions()  {
 
@@ -1299,17 +1292,17 @@ namespace Rivet {
       return false;
     }
 
-    //@}
+    /// @}
 
   private:
 
     /// Histograms
-    //@{
+    /// @{
     Histo1DPtr _h_HTlep_all, _h_HTjets_all, _h_MET_all, _h_Meff_all, _h_min_pT_all, _h_mT_all;
     Histo1DPtr _h_pt_1_3l, _h_pt_2_3l, _h_pt_3_3l, _h_pt_1_2ltau, _h_pt_2_2ltau, _h_pt_3_2ltau;
     Histo1DPtr _h_e_n, _h_mu_n, _h_tau_n;
     Histo1DPtr _h_excluded;
-    //@}
+    /// @}
 
     /// Fiducial efficiencies to model the effects of the ATLAS detector
     bool _use_fiducial_lepton_efficiency;
