@@ -4,7 +4,7 @@
 #include "Rivet/Projections/FastJets.hh"
 #include "Rivet/Projections/IdentifiedFinalState.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/VetoedFinalState.hh"
 
 namespace Rivet {
@@ -19,7 +19,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -37,14 +37,14 @@ namespace Rivet {
       // Electrons and muons in Fiducial PS
       PromptFinalState leptons(fs_z && (Cuts::abspid == PID::ELECTRON || Cuts::abspid == PID::MUON));
       leptons.acceptTauDecays(false);
-      DressedLeptons dressedleptons(photons, leptons, 0.1, FS_Zlept, true);
-      declare(dressedleptons, "DressedLeptons");
+      LeptonFinder dressedleptons(leptons, photons, 0.1, FS_Zlept);
+      declare(dressedleptons, "LeptonFinder");
 
       // Electrons and muons in Total PS
       PromptFinalState leptons_total(Cuts::abspid == PID::ELECTRON || Cuts::abspid == PID::MUON);
       leptons_total.acceptTauDecays(false);
-      DressedLeptons dressedleptonsTotal(photons, leptons_total, 0.1, Cuts::open(), true);
-      declare(dressedleptonsTotal, "DressedLeptonsTotal");
+      LeptonFinder dressedleptonsTotal(leptons_total, photons, 0.1);
+      declare(dressedleptonsTotal, "LeptonFinderTotal");
 
       // Neutrinos
       IdentifiedFinalState nu_id;
@@ -57,33 +57,34 @@ namespace Rivet {
       // Jets
       VetoedFinalState veto;
       veto.addVetoOnThisFinalState(dressedleptons);
-      FastJets jets(veto, FastJets::ANTIKT, 0.4);
+      FastJets jets(veto, JetAlg::ANTIKT, 0.4);
       declare(jets, "Jets");
 
       // Book histograms
-      book(_h["eee"]       , 1, 1, 1);
-      book(_h["mee"]       , 1, 1, 2);
-      book(_h["emm"]       , 1, 1, 3);
-      book(_h["mmm"]       , 1, 1, 4);
-      book(_h["fid"]       , 1, 1, 5);
-      book(_h["eee_Plus"]  , 2, 1, 1);
-      book(_h["mee_Plus"]  , 2, 1, 2);
-      book(_h["emm_Plus"]  , 2, 1, 3);
-      book(_h["mmm_Plus"]  , 2, 1, 4);
-      book(_h["fid_Plus"]  , 2, 1, 5);
-      book(_h["eee_Minus"] , 3, 1, 1);
-      book(_h["mee_Minus"] , 3, 1, 2);
-      book(_h["emm_Minus"] , 3, 1, 3);
-      book(_h["mmm_Minus"] , 3, 1, 4);
-      book(_h["fid_Minus"] , 3, 1, 5);
-      book(_h["total"]     , 5, 1, 1);
-      book(_h["Njets"]     , 27, 1, 1);
-      book(_h["Njets_norm"], 41, 1, 1);
+      book(_i["eee"]       , 1, 1, 1);
+      book(_i["mee"]       , 1, 1, 2);
+      book(_i["emm"]       , 1, 1, 3);
+      book(_i["mmm"]       , 1, 1, 4);
+      book(_i["fid"]       , 1, 1, 5);
+      book(_i["eee_Plus"]  , 2, 1, 1);
+      book(_i["mee_Plus"]  , 2, 1, 2);
+      book(_i["emm_Plus"]  , 2, 1, 3);
+      book(_i["mmm_Plus"]  , 2, 1, 4);
+      book(_i["fid_Plus"]  , 2, 1, 5);
+      book(_i["eee_Minus"] , 3, 1, 1);
+      book(_i["mee_Minus"] , 3, 1, 2);
+      book(_i["emm_Minus"] , 3, 1, 3);
+      book(_i["mmm_Minus"] , 3, 1, 4);
+      book(_i["fid_Minus"] , 3, 1, 5);
+      book(_i["total"]     , 5, 1, 1);
+      
+      book(_ss["Njets"]     , 27, 1, 1);
+      book(_ss["Njets_norm"], 41, 1, 1);
 
-      bookHandler("ZpT",	             12);
+      bookHandler("ZpT",	       12);
       bookHandler("ZpT_Plus",          13);
       bookHandler("ZpT_Minus",         14);
-      bookHandler("WpT",	             15);
+      bookHandler("WpT",	       15);
       bookHandler("WpT_Plus",          16);
       bookHandler("WpT_Minus",         17);
       bookHandler("mTWZ",              18);
@@ -92,7 +93,7 @@ namespace Rivet {
       bookHandler("pTv",               21);
       bookHandler("pTv_Plus",          22);
       bookHandler("pTv_Minus",         23);
-      bookHandler("Deltay",	           24);
+      bookHandler("Deltay",	       24);
       bookHandler("Deltay_Plus",       25);
       bookHandler("Deltay_Minus",      26);
       bookHandler("mjj",               28);
@@ -103,9 +104,9 @@ namespace Rivet {
       bookHandler("WpT_norm",          33);
       bookHandler("mTWZ_norm",         34);
       bookHandler("pTv_norm", 	       35);
-      bookHandler("pTv_Plus_norm",	   36);
-      bookHandler("pTv_Minus_norm",	   37);
-      bookHandler("Deltay_norm",	     38);
+      bookHandler("pTv_Plus_norm",     36);
+      bookHandler("pTv_Minus_norm",    37);
+      bookHandler("Deltay_norm",       38);
       bookHandler("Deltay_Minus_norm", 39);
       bookHandler("Deltay_Plus_norm",  40);
       bookHandler("mjj_norm",          42);
@@ -122,11 +123,11 @@ namespace Rivet {
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
-
-      const vector<DressedLepton>& dressedleptons = apply<DressedLeptons>(event, "DressedLeptons").dressedLeptons();
-      const vector<DressedLepton>& dressedleptonsTotal = apply<DressedLeptons>(event, "DressedLeptonsTotal").dressedLeptons();
+      if(_edges.empty()) _edges = _ss["Njets"]->xEdges();
+      const DressedLeptons& dressedleptons = apply<LeptonFinder>(event, "LeptonFinder").dressedLeptons();
+      const DressedLeptons& dressedleptonsTotal = apply<LeptonFinder>(event, "LeptonFinderTotal").dressedLeptons();
       const Particles& neutrinos = apply<PromptFinalState>(event, "Neutrinos").particlesByPt();
-      Jets jets = apply<JetAlg>(event, "Jets").jetsByPt( (Cuts::abseta < 4.5) && (Cuts::pT > 25*GeV) );
+      Jets jets = apply<JetFinder>(event, "Jets").jetsByPt( (Cuts::abseta < 4.5) && (Cuts::pT > 25*GeV) );
 
       if ((dressedleptonsTotal.size()<3) || (neutrinos.size()<1)) vetoEvent;
 
@@ -189,7 +190,7 @@ namespace Rivet {
 
       FourMomentum ZbosonTotal   = dressedleptonsTotal[i].momentum()+dressedleptonsTotal[j].momentum();
 
-      if ( (ZbosonTotal.mass() >= 66*GeV) && (ZbosonTotal.mass() <= 116*GeV) ) _h["total"]->fill(8000);
+      if ( (ZbosonTotal.mass() >= 66*GeV) && (ZbosonTotal.mass() <= 116*GeV) ) _i["total"]->fill(8000);
 
       //---end Total PS
 
@@ -281,19 +282,19 @@ namespace Rivet {
 
       double AbsDeltay = fabs(Zboson.rapidity()-Wlepton.rapidity());
 
-      if (EventType == 3) _h["eee"]->fill(8000.);
-      if (EventType == 2) _h["mee"]->fill(8000.);
-      if (EventType == 1) _h["emm"]->fill(8000.);
-      if (EventType == 0) _h["mmm"]->fill(8000.);
-      _h["fid"]->fill(8000.);
+      if (EventType == 3) _i["eee"]->fill(8000);
+      if (EventType == 2) _i["mee"]->fill(8000);
+      if (EventType == 1) _i["emm"]->fill(8000);
+      if (EventType == 0) _i["mmm"]->fill(8000);
+      _i["fid"]->fill(8000);
 
       if (EventCharge == 1) {
 
-        if (EventType == 3) _h["eee_Plus"]->fill(8000.);
-        if (EventType == 2) _h["mee_Plus"]->fill(8000.);
-        if (EventType == 1) _h["emm_Plus"]->fill(8000.);
-        if (EventType == 0) _h["mmm_Plus"]->fill(8000.);
-        _h["fid_Plus"]->fill(8000.);
+        if (EventType == 3) _i["eee_Plus"]->fill(8000);
+        if (EventType == 2) _i["mee_Plus"]->fill(8000);
+        if (EventType == 1) _i["emm_Plus"]->fill(8000);
+        if (EventType == 0) _i["mmm_Plus"]->fill(8000);
+        _i["fid_Plus"]->fill(8000);
 
         _h["Deltay_Plus"]->fill(AbsDeltay);
         _h["Deltay_Plus_norm"]->fill(AbsDeltay);
@@ -306,11 +307,11 @@ namespace Rivet {
 
       } else {
 
-        if (EventType == 3) _h["eee_Minus"]->fill(8000.);
-        if (EventType == 2) _h["mee_Minus"]->fill(8000.);
-        if (EventType == 1) _h["emm_Minus"]->fill(8000.);
-        if (EventType == 0) _h["mmm_Minus"]->fill(8000.);
-        _h["fid_Minus"]->fill(8000.);
+        if (EventType == 3) _i["eee_Minus"]->fill(8000);
+        if (EventType == 2) _i["mee_Minus"]->fill(8000);
+        if (EventType == 1) _i["emm_Minus"]->fill(8000);
+        if (EventType == 0) _i["mmm_Minus"]->fill(8000);
+        _i["fid_Minus"]->fill(8000);
 
         _h["Deltay_Minus"]->fill(AbsDeltay);
         _h["Deltay_Minus_norm"]->fill(AbsDeltay);
@@ -329,9 +330,9 @@ namespace Rivet {
       fillWithOverflow("pTv", neutrinos[0].pt()/GeV, 90);
 
       _h["Deltay"]->fill(AbsDeltay);
-
-      fillWithOverflow("Njets", jets.size(), 5);
-      fillWithOverflow("Njets_norm", jets.size(), 5);
+      size_t njets = min(jets.size(),size_t(5));
+      _ss["Njets"     ]->fill(_edges[njets]);
+      _ss["Njets_norm"]->fill(_edges[njets]);
       fillWithOverflow("ZpT_norm", Zboson.pT()/GeV, 220);
       fillWithOverflow("WpT_norm", Wboson.pT()/GeV, 220);
       fillWithOverflow("mTWZ_norm", mTWZ, 600);
@@ -376,53 +377,56 @@ namespace Rivet {
 
       float totalBR= 4*0.1086*0.033658; // W and Z leptonic branching fractions
 
-      for (map<string, Histo1DPtr>::iterator it = _h.begin(); it != _h.end(); ++it) {
-        if (it->first.find("total") != string::npos)        scale(it->second, sf_pb/totalBR);
-        else if (it->first.find("norm") != string::npos)    normalize(it->second);
-        else if (it->first.find("fid") != string::npos)     scale(it->second, sf_fb/4.);
-        else if (it->first.find("Njets") != string::npos)   scale(it->second, sf_fb/4.);
-        else if (it->first.find("ZpT") != string::npos)     scale(it->second, sf_fb/4.);
-        else if (it->first.find("WpT") != string::npos)     scale(it->second, sf_fb/4.);
-        else if (it->first.find("mTWZ") != string::npos)    scale(it->second, sf_fb/4.);
-        else if (it->first.find("pTv") != string::npos)     scale(it->second, sf_fb/4.);
-        else if (it->first.find("Deltay") != string::npos)  scale(it->second, sf_fb/4.);
-        else if (it->first.find("mjj") != string::npos)     scale(it->second, sf_fb/4.);
-        else                                                scale(it->second, sf_fb);
+      for (auto& it : _h) {
+        if (it.first.find("total") != string::npos)        scale(it.second, sf_pb/totalBR);
+        else if (it.first.find("norm") != string::npos)    normalize(it.second);
+        else if (it.first.find("fid") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("Njets") != string::npos)   scale(it.second, sf_fb/4.);
+        else if (it.first.find("ZpT") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("WpT") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("mTWZ") != string::npos)    scale(it.second, sf_fb/4.);
+        else if (it.first.find("pTv") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("Deltay") != string::npos)  scale(it.second, sf_fb/4.);
+        else if (it.first.find("mjj") != string::npos)     scale(it.second, sf_fb/4.);
+        else                                               scale(it.second, sf_fb);
       }
-      for (map<string, Scatter2DPtr>::iterator it = _s.begin(); it != _s.end(); ++it) {
-        // @todo replace with new YODA object?
-        makeScatterWithoutDividingByBinwidth(it->first);
-        // @todo need this to disappear if we want reentrant safety
-        removeAnalysisObject(_h[it->first]);
+      for (auto& it : _i) {
+        if (it.first.find("total") != string::npos)        scale(it.second, sf_pb/totalBR);
+        else if (it.first.find("norm") != string::npos)    normalize(it.second);
+        else if (it.first.find("fid") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("Njets") != string::npos)   scale(it.second, sf_fb/4.);
+        else if (it.first.find("ZpT") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("WpT") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("mTWZ") != string::npos)    scale(it.second, sf_fb/4.);
+        else if (it.first.find("pTv") != string::npos)     scale(it.second, sf_fb/4.);
+        else if (it.first.find("Deltay") != string::npos)  scale(it.second, sf_fb/4.);
+        else if (it.first.find("mjj") != string::npos)     scale(it.second, sf_fb/4.);
+        else                                               scale(it.second, sf_fb);
       }
+      for (auto& it : _s) {
+        barchart(_h[it.first], it.second);
+        removeAnalysisObject(_h[it.first]);
+      }
+      // normalisation of njets
+      scale(_ss["Njets"], sf_fb/4.);
+      normalize(_ss["Njets_norm"]);
     }
 
-    void makeScatterWithoutDividingByBinwidth(const string& tag) {
-      vector<Point2D> points;
-      //size_t nBins = _dummy->numBins();
-      for (const HistoBin1D &bin : _h[tag]->bins()) {
-        double  x = bin.midpoint();
-        double  y = bin.sumW();
-        double ex = bin.xWidth()/2;
-        double ey = sqrt(bin.sumW2());
-        points.push_back(Point2D(x, y, ex, ey));
-      }
-      _s[tag]->addPoints(points);
-    }
-
-
-    //@}
+    /// @}
 
 
   private:
 
     /// @name Histograms
-    //@{
+    /// @{
 
      map<string, Histo1DPtr> _h;
-     map<string, Scatter2DPtr> _s;
+     map<string, BinnedHistoPtr<int> > _i;
+     map<string, BinnedHistoPtr<string> > _ss;
+     map<string, Estimate1DPtr> _s;
+     vector<string> _edges;
 
-     //@}
+     /// @}
 
      double MZ_PDG = 91.1876;
      double MW_PDG = 83.385;
@@ -431,7 +435,6 @@ namespace Rivet {
 
   };
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(ATLAS_2016_I1426523);
 
 }
