@@ -4,10 +4,9 @@
 #include "Rivet/Projections/VetoedFinalState.hh"
 #include "Rivet/Projections/InvisibleFinalState.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/MissingMomentum.hh"
 #include "Rivet/Projections/FastJets.hh"
-#include "Rivet/Tools/BinnedHistogram.hh"
 
 namespace Rivet {
 
@@ -30,34 +29,41 @@ namespace Rivet {
 
       FinalState all_photons(fs, Cuts::abspid == PID::PHOTON);
 
-      PromptFinalState photons(all_photons, false);
+      PromptFinalState photons(all_photons, TauDecaysAs::NONPROMPT);
       declare(photons, "photons");
 
-      PromptFinalState electrons(Cuts::abspid == PID::ELECTRON, true);
+      PromptFinalState electrons(Cuts::abspid == PID::ELECTRON, TauDecaysAs::PROMPT);
       declare(electrons, "electrons");
 
-      DressedLeptons dressedelectrons(photons, electrons, 0.1, lep_cuts, true);
+      LeptonFinder dressedelectrons(electrons, photons, 0.1, lep_cuts);
       declare(dressedelectrons, "dressedelectrons");
 
-      DressedLeptons ewdressedelectrons(all_photons, electrons, 0.1, eta_full, true);
+      LeptonFinder ewdressedelectrons(electrons, all_photons, 0.1, eta_full);
       declare(ewdressedelectrons, "ewdressedelectrons");
 
-      PromptFinalState muons(Cuts::abspid == PID::MUON, true);
+      PromptFinalState muons(Cuts::abspid == PID::MUON, TauDecaysAs::PROMPT);
       declare(muons, "muons");
 
-      DressedLeptons dressedmuons(photons, muons, 0.1, lep_cuts, true);
+      LeptonFinder dressedmuons(muons, photons, 0.1, lep_cuts);
       declare(dressedmuons, "dressedmuons");
 
-      DressedLeptons ewdressedmuons(all_photons, muons, 0.1, eta_full, true);
+      LeptonFinder ewdressedmuons(muons, all_photons, 0.1, eta_full);
       declare(ewdressedmuons, "ewdressedmuons");
 
-      const InvisibleFinalState neutrinos(true, true);
+      InvisibleFinalState neutrinos(OnlyPrompt::YES, TauDecaysAs::PROMPT);
+
+      VetoedFinalState vfs(fs);
+      vfs.addVetoOnThisFinalState(dressedelectrons);
+      vfs.addVetoOnThisFinalState(dressedmuons);
+      vfs.addVetoOnThisFinalState(neutrinos);
+      FastJets jets(vfs, JetAlg::ANTIKT, 0.4, JetMuons::ALL, JetInvisibles::ALL);
+      declare(jets, "boosted_jets");
 
       VetoedFinalState vfs_res(fs);
       vfs_res.addVetoOnThisFinalState(ewdressedelectrons);
       vfs_res.addVetoOnThisFinalState(ewdressedmuons);
       vfs_res.addVetoOnThisFinalState(neutrinos);
-      FastJets jets_res(vfs_res, FastJets::ANTIKT, 0.4, JetAlg::Muons::ALL, JetAlg::Invisibles::ALL);
+      FastJets jets_res(vfs_res, JetAlg::ANTIKT, 0.4, JetMuons::ALL, JetInvisibles::ALL);
       declare(jets_res, "resolved_jets");
 
       declare(MissingMomentum(), "MissingMomentum");
@@ -146,7 +152,7 @@ namespace Rivet {
       book_hist("absPout",25);
       book_hist("deltaPhi_tt",29);
       book_hist("HT_tt",33);
-      book_hist("extrajet_n",37);
+      book_disc("extrajet_n",37);
       book_hist("ttbar_abs_y_fine",41);
       book_hist("abs_y_boost",45);
       book_hist("chi_tt",49);
@@ -181,8 +187,8 @@ namespace Rivet {
       book_hist("boosted_rc_Pout_lep",872);
       book_hist("boosted_rc_chi_tt",868);
       book_hist("boosted_rc_HT",876);
-      book_hist("hadTop_boosted_rc_subjets",884);
-      book_hist("boosted_rc_extrajet",880);
+      book_disc("hadTop_boosted_rc_subjets",884);
+      book_disc("boosted_rc_extrajet",880);
       book_hist("ttbar_boosted_rc_m",864);
       book_hist("ttbar_boosted_rc_pt",856);
       book_hist("ttbar_boosted_rc_Rapidity",860);
@@ -199,8 +205,8 @@ namespace Rivet {
     void Resolved_selection(const Event& event) {
 
       // Get the selected objects, using the projections.
-      vector<DressedLepton> electrons = apply<DressedLeptons>(event, "dressedelectrons").dressedLeptons();
-      vector<DressedLepton> muons     = apply<DressedLeptons>(event, "dressedmuons").dressedLeptons();
+      DressedLeptons electrons = apply<LeptonFinder>(event, "dressedelectrons").dressedLeptons();
+      DressedLeptons muons     = apply<LeptonFinder>(event, "dressedmuons").dressedLeptons();
       const Jets& jets = apply<FastJets>(event, "resolved_jets").jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta < 2.5);
       FourMomentum met = apply<MissingMomentum>(event, "MissingMomentum").missingMomentum();
 
@@ -286,45 +292,43 @@ namespace Rivet {
       int extrajet_n = jet_multiplicity - 4;
       int new_jet_multi = TransformJetMultiplicity(jet_multiplicity);
       int new_jet_multi_for_ttbar_m = TransformJetMultiplicity_for_ttbar_m(jet_multiplicity);
-      int new_extrajet_multi =TransformExtrajetMultiplicity(extrajet_n);
+      const string new_extrajet_multi = TransformExtrajetMultiplicity(extrajet_n);
 
-      _h_multi["top_had_pt_Pout_multi"].fill(ppseudotophadron.pt()/GeV, Pout);
-      _h_multi["top_had_pt_absPout_multi"].fill(ppseudotophadron.pt()/GeV, absPout);
-      _h_multi["ttbar_m_top_had_pt_multi"].fill(pttbar.mass()/GeV, ppseudotophadron.pt()/GeV);
-      _h_multi["ttbar_m_ttbar_pt_multi"].fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
-      _h_multi["ttbar_pt_top_had_pt_multi"].fill(pttbar.pt()/GeV, ppseudotophadron.pt()/GeV);
-      _h_multi["ttbar_abs_y_ttbar_pt_multi"].fill(pttbar.absrap(), pttbar.pt()/GeV);
-      _h_multi["ttbar_abs_y_ttbar_m_multi"].fill(pttbar.absrap(), pttbar.mass()/GeV);
-      _h_multi["top_had_abs_y_top_had_pt_multi"].fill(ppseudotophadron.absrap(), ppseudotophadron.pt()/GeV);
+      _h_multi["top_had_pt_absPout_multi"]->fill(ppseudotophadron.pt()/GeV, absPout);
+      _h_multi["ttbar_m_top_had_pt_multi"]->fill(pttbar.mass()/GeV, ppseudotophadron.pt()/GeV);
+      _h_multi["ttbar_m_ttbar_pt_multi"]->fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
+      _h_multi["ttbar_pt_top_had_pt_multi"]->fill(pttbar.pt()/GeV, ppseudotophadron.pt()/GeV);
+      _h_multi["ttbar_abs_y_ttbar_pt_multi"]->fill(pttbar.absrap(), pttbar.pt()/GeV);
+      _h_multi["ttbar_abs_y_ttbar_m_multi"]->fill(pttbar.absrap(), pttbar.mass()/GeV);
+      _h_multi["top_had_abs_y_top_had_pt_multi"]->fill(ppseudotophadron.absrap(), ppseudotophadron.pt()/GeV);
 
-      _h_multi["ttbar_pt_jet_n_multi"].fill(new_jet_multi, pttbar.pt()/GeV);
-      _h_multi["ttbar_m_jet_n_multi"].fill(new_jet_multi_for_ttbar_m, pttbar.mass()/GeV);
-      _h_multi["chi_tt_jet_n_multi"].fill(new_jet_multi, chi_ttbar);
-      _h_multi["absPout_jet_n_multi"].fill(new_jet_multi, absPout);
-      _h_multi["deltaPhi_tt_jet_n_multi"].fill(new_jet_multi, deltaPhi_ttbar);
-      _h_multi["HT_tt_jet_n_multi"].fill(new_jet_multi, HT_ttbar/GeV);
-      _h_multi["top_had_pt_jet_n_multi"].fill(new_jet_multi, ppseudotophadron.pt()/GeV);
-      _h_multi["top_had_abs_y_jet_n_multi"].fill(new_jet_multi, ppseudotophadron.absrap());
-      _h_multi["ttbar_abs_y_jet_n_multi"].fill(new_jet_multi, pttbar.absrap());
+      _h_multi["ttbar_pt_jet_n_multi"]->fill(new_jet_multi, pttbar.pt()/GeV);
+      _h_multi["ttbar_m_jet_n_multi"]->fill(new_jet_multi_for_ttbar_m, pttbar.mass()/GeV);
+      _h_multi["chi_tt_jet_n_multi"]->fill(new_jet_multi, chi_ttbar);
+      _h_multi["absPout_jet_n_multi"]->fill(new_jet_multi, absPout);
+      _h_multi["deltaPhi_tt_jet_n_multi"]->fill(new_jet_multi, deltaPhi_ttbar);
+      _h_multi["HT_tt_jet_n_multi"]->fill(new_jet_multi, HT_ttbar/GeV);
+      _h_multi["top_had_pt_jet_n_multi"]->fill(new_jet_multi, ppseudotophadron.pt()/GeV);
+      _h_multi["top_had_abs_y_jet_n_multi"]->fill(new_jet_multi, ppseudotophadron.absrap());
+      _h_multi["ttbar_abs_y_jet_n_multi"]->fill(new_jet_multi, pttbar.absrap());
 
-      _h_multi["top_had_pt_Pout_multi_norm"].fill(ppseudotophadron.pt()/GeV, Pout);
-      _h_multi["top_had_pt_absPout_multi_norm"].fill(ppseudotophadron.pt()/GeV, absPout);
-      _h_multi["ttbar_m_top_had_pt_multi_norm"].fill(pttbar.mass()/GeV, ppseudotophadron.pt()/GeV);
-      _h_multi["ttbar_m_ttbar_pt_multi_norm"].fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
-      _h_multi["ttbar_pt_top_had_pt_multi_norm"].fill(pttbar.pt()/GeV, ppseudotophadron.pt()/GeV);
-      _h_multi["ttbar_abs_y_ttbar_pt_multi_norm"].fill(pttbar.absrap(), pttbar.pt()/GeV);
-      _h_multi["ttbar_abs_y_ttbar_m_multi_norm"].fill(pttbar.absrap(), pttbar.mass()/GeV);
-      _h_multi["top_had_abs_y_top_had_pt_multi_norm"].fill(ppseudotophadron.absrap(), ppseudotophadron.pt()/GeV);
+      _h_multi["top_had_pt_absPout_multi_norm"]->fill(ppseudotophadron.pt()/GeV, absPout);
+      _h_multi["ttbar_m_top_had_pt_multi_norm"]->fill(pttbar.mass()/GeV, ppseudotophadron.pt()/GeV);
+      _h_multi["ttbar_m_ttbar_pt_multi_norm"]->fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
+      _h_multi["ttbar_pt_top_had_pt_multi_norm"]->fill(pttbar.pt()/GeV, ppseudotophadron.pt()/GeV);
+      _h_multi["ttbar_abs_y_ttbar_pt_multi_norm"]->fill(pttbar.absrap(), pttbar.pt()/GeV);
+      _h_multi["ttbar_abs_y_ttbar_m_multi_norm"]->fill(pttbar.absrap(), pttbar.mass()/GeV);
+      _h_multi["top_had_abs_y_top_had_pt_multi_norm"]->fill(ppseudotophadron.absrap(), ppseudotophadron.pt()/GeV);
 
-      _h_multi["ttbar_pt_jet_n_multi_norm"].fill(new_jet_multi, pttbar.pt());
-      _h_multi["ttbar_m_jet_n_multi_norm"].fill(new_jet_multi_for_ttbar_m, pttbar.mass());
-      _h_multi["chi_tt_jet_n_multi_norm"].fill(new_jet_multi, chi_ttbar);
-      _h_multi["absPout_jet_n_multi_norm"].fill(new_jet_multi, absPout);
-      _h_multi["deltaPhi_tt_jet_n_multi_norm"].fill(new_jet_multi, deltaPhi_ttbar);
-      _h_multi["HT_tt_jet_n_multi_norm"].fill(new_jet_multi, HT_ttbar/GeV);
-      _h_multi["top_had_pt_jet_n_multi_norm"].fill(new_jet_multi, ppseudotophadron.pt()/GeV);
-      _h_multi["top_had_abs_y_jet_n_multi_norm"].fill(new_jet_multi, ppseudotophadron.absrap());
-      _h_multi["ttbar_abs_y_jet_n_multi_norm"].fill(new_jet_multi, pttbar.absrap());
+      _h_multi["ttbar_pt_jet_n_multi_norm"]->fill(new_jet_multi, pttbar.pt());
+      _h_multi["ttbar_m_jet_n_multi_norm"]->fill(new_jet_multi_for_ttbar_m, pttbar.mass());
+      _h_multi["chi_tt_jet_n_multi_norm"]->fill(new_jet_multi, chi_ttbar);
+      _h_multi["absPout_jet_n_multi_norm"]->fill(new_jet_multi, absPout);
+      _h_multi["deltaPhi_tt_jet_n_multi_norm"]->fill(new_jet_multi, deltaPhi_ttbar);
+      _h_multi["HT_tt_jet_n_multi_norm"]->fill(new_jet_multi, HT_ttbar/GeV);
+      _h_multi["top_had_pt_jet_n_multi_norm"]->fill(new_jet_multi, ppseudotophadron.pt()/GeV);
+      _h_multi["top_had_abs_y_jet_n_multi_norm"]->fill(new_jet_multi, ppseudotophadron.absrap());
+      _h_multi["ttbar_abs_y_jet_n_multi_norm"]->fill(new_jet_multi, pttbar.absrap());
 
       _h["chi_tt"]->fill(chi_ttbar);
       _h["deltaPhi_tt"]->fill(deltaPhi_ttbar);
@@ -338,7 +342,7 @@ namespace Rivet {
       _h["ttbar_abs_y_fine"]->fill(pttbar.absrap());
       _h["leading_top_pt"]->fill(Leading_top_pt/GeV);
       _h["subleading_top_pt"]->fill(Subleading_top_pt/GeV);
-      _h["extrajet_n"]->fill(new_extrajet_multi+1);
+      _d["extrajet_n"]->fill(new_extrajet_multi);
 
       _h["chi_tt_norm"]->fill(chi_ttbar);
       _h["deltaPhi_tt_norm"]->fill(deltaPhi_ttbar);
@@ -352,15 +356,15 @@ namespace Rivet {
       _h["ttbar_abs_y_fine_norm"]->fill(pttbar.absrap());
       _h["leading_top_pt_norm"]->fill(Leading_top_pt/GeV);
       _h["subleading_top_pt_norm"]->fill(Subleading_top_pt/GeV);
-      _h["extrajet_n_norm"]->fill(new_extrajet_multi+1);
+      _d["extrajet_n_norm"]->fill(new_extrajet_multi);
     }
 
     void Boosted_selection(const Event& event) {
 
       //Projections
-      vector<DressedLepton> electrons = apply<DressedLeptons>(event, "dressedelectrons").dressedLeptons();
-      vector<DressedLepton> muons = apply<DressedLeptons>(event, "dressedmuons").dressedLeptons();
-      const Jets& jets = apply<FastJets>(event, "resolved_jets").jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta <= 2.5);
+      DressedLeptons electrons = apply<LeptonFinder>(event, "dressedelectrons").dressedLeptons();
+      DressedLeptons muons = apply<LeptonFinder>(event, "dressedmuons").dressedLeptons();
+      const Jets& jets = apply<FastJets>(event, "boosted_jets").jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta <= 2.5);
       const FourMomentum& met = apply<MissingMomentum>(event, "MissingMomentum").missingMomentum();
 
       if (jets.size() < 2)  vetoEvent;
@@ -380,7 +384,7 @@ namespace Rivet {
 
       // trim the jets
       Jets TrimmedJets;
-      for (PseudoJet pjet : reclustered_jets) {
+      for (const PseudoJet& pjet : reclustered_jets) {
         PseudoJet ptrim = trimmer(pjet);
         if (ptrim.perp() < 350*GeV)  continue;
         if (fabs(ptrim.eta()) > 2.0) continue;
@@ -396,7 +400,7 @@ namespace Rivet {
         TrimmedJets += Jet(ptrim, constituents);
       }
       Cut trim_selection = Cuts::abseta < 2.0 && Cuts::pT > 200*GeV && Cuts::massIn(120*GeV, 220*GeV);
-      ifilter_select(isortByPt(TrimmedJets), trim_selection);
+      iselect(isortByPt(TrimmedJets), trim_selection);
       if (TrimmedJets.empty())  vetoEvent;
 
 
@@ -435,7 +439,7 @@ namespace Rivet {
       }
       if (!hasHadTopCandidate)  vetoEvent;
 
-      Jets LepTopCandidates = filter_discard(jets, [&](const Jet& j) {
+      Jets LepTopCandidates = discard(jets, [&](const Jet& j) {
           return deltaR(j, HadTopCandidate) < 1.5 || deltaR(j, *lepton) > 2.0;
         });
       if (LepTopCandidates.empty()) vetoEvent;
@@ -469,34 +473,34 @@ namespace Rivet {
       double absPout_lep = fabs(vpseudotoplepton.dot((vpseudotophadron.cross(z_versor))/(vpseudotophadron.cross(z_versor).mod())));
       size_t extrajet = smallRjets.size() - subjets -1;
 
-      size_t new_subjets_multi = TransformExtrajetMultiplicity_boosted(subjets);
-      size_t new_extrajet_multi = TransformExtrajetMultiplicity_boosted(extrajet);
+      const string new_subjets_multi = TransformExtrajetMultiplicity_boosted(subjets);
+      const string new_extrajet_multi = TransformExtrajetMultiplicity_boosted(extrajet);
       size_t new_extrajet_multi_pttop = TransformJetMultiplicity_pttop(extrajet);
       size_t new_extrajet_multi_ptttbar = TransformJetMultiplicity_ptttbar(extrajet);
       size_t new_extrajet_multi_mttbar = TransformJetMultiplicity_mttbar(extrajet);
 
-      _h_multi["boosted_rc_pttop_etatop_multi"].fill(HadronicTop.absrap(), HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_pttop_etattbar_multi"].fill(pttbar.absrap(), HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_pttop_ptttbar_multi"].fill(pttbar.pt()/GeV, HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_pttop_mttbar_multi"].fill(pttbar.mass()/GeV, HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_mttbar_etattbar_multi"].fill(pttbar.absrap(), pttbar.mass()/GeV);
-      _h_multi["boosted_rc_mttbar_ptttbar_multi"].fill(pttbar.pt()/GeV, pttbar.mass()/GeV);
-      _h_multi["boosted_rc_mttbar_HT_multi"].fill(HT_ttbar, pttbar.mass()/GeV);
+      _h_multi["boosted_rc_pttop_etatop_multi"]->fill(HadronicTop.absrap(), HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_pttop_etattbar_multi"]->fill(pttbar.absrap(), HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_pttop_ptttbar_multi"]->fill(pttbar.pt()/GeV, HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_pttop_mttbar_multi"]->fill(pttbar.mass()/GeV, HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_mttbar_etattbar_multi"]->fill(pttbar.absrap(), pttbar.mass()/GeV);
+      _h_multi["boosted_rc_mttbar_ptttbar_multi"]->fill(pttbar.pt()/GeV, pttbar.mass()/GeV);
+      _h_multi["boosted_rc_mttbar_HT_multi"]->fill(HT_ttbar, pttbar.mass()/GeV);
 
-      _h_multi["boosted_rc_pttop_extrajet_multi"].fill(new_extrajet_multi_pttop, HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_ptttbar_extrajet_multi"].fill(new_extrajet_multi_ptttbar, pttbar.pt()/GeV);
-      _h_multi["boosted_rc_mttbar_extrajet_multi"].fill(new_extrajet_multi_mttbar, pttbar.mass()/GeV);
+      _h_multi["boosted_rc_pttop_extrajet_multi"]->fill(new_extrajet_multi_pttop, HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_ptttbar_extrajet_multi"]->fill(new_extrajet_multi_ptttbar, pttbar.pt()/GeV);
+      _h_multi["boosted_rc_mttbar_extrajet_multi"]->fill(new_extrajet_multi_mttbar, pttbar.mass()/GeV);
 
-      _h_multi["boosted_rc_pttop_etatop_multi_norm"].fill(HadronicTop.absrap(), HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_pttop_etattbar_multi_norm"].fill(pttbar.absrap(), HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_pttop_ptttbar_multi_norm"].fill(pttbar.pt()/GeV, HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_pttop_mttbar_multi_norm"].fill(pttbar.mass()/GeV, HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_mttbar_etattbar_multi_norm"].fill(pttbar.absrap(), pttbar.mass()/GeV);
-      _h_multi["boosted_rc_mttbar_ptttbar_multi_norm"].fill(pttbar.pt()/GeV, pttbar.mass()/GeV);
-      _h_multi["boosted_rc_mttbar_HT_multi_norm"].fill(HT_ttbar/GeV, pttbar.mass()/GeV);
-      _h_multi["boosted_rc_pttop_extrajet_multi_norm"].fill(new_extrajet_multi_pttop, HadronicTop.pt()/GeV);
-      _h_multi["boosted_rc_ptttbar_extrajet_multi_norm"].fill(new_extrajet_multi_ptttbar, pttbar.pt()/GeV);
-      _h_multi["boosted_rc_mttbar_extrajet_multi_norm"].fill(new_extrajet_multi_mttbar, pttbar.mass()/GeV);
+      _h_multi["boosted_rc_pttop_etatop_multi_norm"]->fill(HadronicTop.absrap(), HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_pttop_etattbar_multi_norm"]->fill(pttbar.absrap(), HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_pttop_ptttbar_multi_norm"]->fill(pttbar.pt()/GeV, HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_pttop_mttbar_multi_norm"]->fill(pttbar.mass()/GeV, HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_mttbar_etattbar_multi_norm"]->fill(pttbar.absrap(), pttbar.mass()/GeV);
+      _h_multi["boosted_rc_mttbar_ptttbar_multi_norm"]->fill(pttbar.pt()/GeV, pttbar.mass()/GeV);
+      _h_multi["boosted_rc_mttbar_HT_multi_norm"]->fill(HT_ttbar/GeV, pttbar.mass()/GeV);
+      _h_multi["boosted_rc_pttop_extrajet_multi_norm"]->fill(new_extrajet_multi_pttop, HadronicTop.pt()/GeV);
+      _h_multi["boosted_rc_ptttbar_extrajet_multi_norm"]->fill(new_extrajet_multi_ptttbar, pttbar.pt()/GeV);
+      _h_multi["boosted_rc_mttbar_extrajet_multi_norm"]->fill(new_extrajet_multi_mttbar, pttbar.mass()/GeV);
 
       _h["hadTop_boosted_rc_pt"]->fill(HadronicTop.pt()/GeV);
       _h["hadTop_boosted_rc_y"]->fill(HadronicTop.absrap());
@@ -505,8 +509,8 @@ namespace Rivet {
       _h["boosted_rc_Pout_lep"]->fill(absPout_lep);
       _h["boosted_rc_chi_tt"]->fill(chi_ttbar);
       _h["boosted_rc_HT"]->fill(HT_ttbar/GeV);
-      _h["hadTop_boosted_rc_subjets"]->fill(new_subjets_multi);
-      _h["boosted_rc_extrajet"]->fill(new_extrajet_multi+1);
+      _d["hadTop_boosted_rc_subjets"]->fill(new_subjets_multi);
+      _d["boosted_rc_extrajet"]->fill(new_extrajet_multi);
       _h["ttbar_boosted_rc_m"]->fill(pttbar.mass()/GeV);
       _h["ttbar_boosted_rc_pt"]->fill(pttbar.pt()/GeV);
       _h["ttbar_boosted_rc_Rapidity"]->fill(pttbar.absrapidity());
@@ -518,31 +522,34 @@ namespace Rivet {
       _h["boosted_rc_Pout_lep_norm"]->fill(absPout_lep);
       _h["boosted_rc_chi_tt_norm"]->fill(chi_ttbar);
       _h["boosted_rc_HT_norm"]->fill(HT_ttbar/GeV);
-      _h["hadTop_boosted_rc_subjets_norm"]->fill(new_subjets_multi);
-      _h["boosted_rc_extrajet_norm"]->fill(new_extrajet_multi+1);
+      _d["hadTop_boosted_rc_subjets_norm"]->fill(new_subjets_multi);
+      _d["boosted_rc_extrajet_norm"]->fill(new_extrajet_multi);
       _h["ttbar_boosted_rc_m_norm"]->fill(pttbar.mass()/GeV);
       _h["ttbar_boosted_rc_pt_norm"]->fill(pttbar.pt()/GeV);
-      _h["ttbar_boosted_rc_Rapidity_norm"]->fill(pttbar.absrap()) ;
+      _h["ttbar_boosted_rc_Rapidity_norm"]->fill(pttbar.absrap());
     }
 
 
     void finalize() {
       // Normalize to cross-section
-      const double sf = crossSection() / sumOfWeights();
+      const double sf = crossSection()/picobarn / sumOfWeights();
       for (auto& hit : _h) {
+        if (hit.first.find("_norm") != string::npos)  normalize(hit.second, 1.0, false);
+        else                                          scale(hit.second, sf);
+      }
+      for (auto& hit : _d) {
         scale(hit.second, sf);
         if (hit.first.find("_norm") != string::npos)  normalize(hit.second, 1.0, false);
       }
       for (auto& hit : _h_multi) {
         if (hit.first.find("_norm") != string::npos) {
-          for (Histo1DPtr& hist : hit.second.histos()) { scale(hist, sf); }
-          const double norm2D = integral2D(hit.second);
-          hit.second.scale(safediv(1.0, norm2D), this);
+          normalizeGroup(hit.second, 1.0, false);
         }
         else {
-          hit.second.scale(sf, this);
+          scale(hit.second, sf);
         }
       }
+      divByGroupWidth(_h_multi);
     }
 
 
@@ -577,54 +584,66 @@ namespace Rivet {
     }
 
 
-    double integral2D(BinnedHistogram& h_multi) {
-      double total_integral = 0;
-      for  (Histo1DPtr& h : h_multi.histos()) {
-        total_integral += h->integral(false);
-      }
-      return total_integral;
-    }
 
 
-    void book2D(string name, std::vector<double>& doubleDiff_bins, size_t table){
-      for (size_t i = 0; i < doubleDiff_bins.size() - 1; ++i) {
-        string nbin = std::to_string(i);
-        // HepData entry has dummy "Table of Contents", 
-        // so need to offset everything by one unit
-        { Histo1DPtr tmp; _h_multi[name].add(doubleDiff_bins[i], doubleDiff_bins[i+1], book(tmp, table+1+i, 1, 1)); }
+    void book2D(const string& name, const std::vector<double>& doubleDiff_bins, size_t table){
+      book(_h_multi[name], doubleDiff_bins);
+      for (auto& b : _h_multi[name]->bins()) {
+        book(b, table+b.index(), 1, 1);
       }
     }
 
 
-    void book_hist(string name, size_t table) {
-      // HepData entry has dummy "Table of Contents", 
+    void book_hist(const string& name, size_t table) {
+      // HepData entry has dummy "Table of Contents",
       // so need to offset everything by one unit
       book(_h[name], table+3, 1, 1);
       book(_h[name+"_norm"], table+1, 1, 1);
     }
 
-    size_t TransformJetMultiplicity(size_t jet_n) { return jet_n > 7 ? 7 : jet_n; }
+    void book_disc(const string& name, size_t table) {
+      // HepData entry has dummy "Table of Contents",
+      // so need to offset everything by one unit
+      book(_d[name], table+3, 1, 1);
+      book(_d[name+"_norm"], table+1, 1, 1);
+    }
 
-    size_t TransformExtrajetMultiplicity(size_t jet_n) { return jet_n > 6 ? 6 : jet_n; }
+    size_t TransformJetMultiplicity(size_t jet_n) const { return jet_n > 7 ? 7 : jet_n; }
 
-    size_t TransformExtrajetMultiplicity_boosted(size_t jet_n) { return jet_n > 4 ? 4 : jet_n; }
+    string TransformExtrajetMultiplicity(size_t jet_n) const {
+      if (jet_n == 0)       return "0.0"s;
+      else if (jet_n == 1)  return "1.0"s;
+      else if (jet_n == 2)  return "2.0"s;
+      else if (jet_n == 3)  return "3.0"s;
+      else if (jet_n == 4)  return "4.0"s;
+      else if (jet_n == 5)  return "5.0"s;
+      else                  return "$\\geq$6.0"s;
+    }
 
-    size_t TransformJetMultiplicity_for_ttbar_m(size_t jet_n) { return jet_n > 6 ? 6 : jet_n; }
+    string TransformExtrajetMultiplicity_boosted(size_t jet_n) const {
+      if (jet_n == 0)       return "0.0"s;
+      else if (jet_n == 1)  return "1.0"s;
+      else if (jet_n == 2)  return "2.0"s;
+      else if (jet_n == 3)  return "3.0"s;
+      else                  return "$\\geq$4.0"s;
+    }
 
-    size_t TransformJetMultiplicity_pttop(size_t jet_n) {
+    size_t TransformJetMultiplicity_for_ttbar_m(size_t jet_n) const { return jet_n > 6 ? 6 : jet_n; }
+
+    size_t TransformJetMultiplicity_pttop(size_t jet_n) const {
       if (jet_n < 2)  return 0;
       if (jet_n == 2)               return 2;
       if (jet_n > 2)                return 3;
       return jet_n;
     }
 
-    size_t TransformJetMultiplicity_ptttbar(size_t jet_n) {
+    size_t TransformJetMultiplicity_ptttbar(size_t jet_n) const {
       if (jet_n < 2)  return 0;
       if (jet_n >= 2)               return 2;
       return jet_n;
     }
 
-    size_t TransformJetMultiplicity_mttbar(size_t jet_n) {
+    size_t TransformJetMultiplicity_mttbar(size_t jet_n) const {
       if (jet_n == 0)  return 0;
       if (jet_n == 1)  return 1;
       if (jet_n >= 2)  return 2;
@@ -632,10 +651,11 @@ namespace Rivet {
     }
 
     /// @name Objects that are used by the event selection decisions
-    ///@{
+    /// @{
     map<string, Histo1DPtr> _h;
-    map<string, BinnedHistogram> _h_multi;
-    ///@}
+    map<string, BinnedHistoPtr<string>> _d;
+    map<string, Histo1DGroupPtr> _h_multi;
+    /// @}
 
   };
 
