@@ -2,7 +2,7 @@
 #include "Rivet/Projections/FinalState.hh"
 #include "Rivet/Projections/VetoedFinalState.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/FastJets.hh"
 #include "Rivet/Projections/InvisibleFinalState.hh"
 
@@ -25,7 +25,7 @@ namespace Rivet {
       FinalState fs(eta_full);
       FinalState fs_neutrino;
 
-      const FinalState all_photons(eta_full && Cuts::abspid == PID::PHOTON);
+      FinalState all_photons(eta_full && Cuts::abspid == PID::PHOTON);
       PromptFinalState photons(all_photons);
       photons.acceptTauDecays(false);
       declare(photons, "photons");
@@ -35,31 +35,31 @@ namespace Rivet {
       electrons.acceptTauDecays(true);
       declare(electrons, "electrons");
 
-      DressedLeptons dressedelectrons(photons, electrons, 0.1, lep_cuts, true, true);
+      LeptonFinder dressedelectrons(electrons, photons, 0.1, lep_cuts, DressingType::CLUSTER);
       declare(dressedelectrons, "dressedelectrons");
 
-      DressedLeptons ewdressedelectrons(all_photons, electrons, 0.1, eta_full, true, true);
+      LeptonFinder ewdressedelectrons(electrons, all_photons, 0.1, eta_full, DressingType::CLUSTER);
       declare(ewdressedelectrons, "ewdressedelectrons");
 
       PromptFinalState muons(eta_full && Cuts::abspid == PID::MUON);
       muons.acceptTauDecays(true);
       declare(muons, "muons");
 
-      DressedLeptons dressedmuons(photons, muons, 0.1, lep_cuts, true, true);
+      LeptonFinder dressedmuons(muons, photons, 0.1, lep_cuts, DressingType::CLUSTER);
       declare(dressedmuons, "dressedmuons");
 
-      DressedLeptons ewdressedmuons(all_photons, muons, 0.1, eta_full, true, true);
+      LeptonFinder ewdressedmuons(muons, all_photons, 0.1, eta_full, DressingType::CLUSTER);
       declare(ewdressedmuons, "ewdressedmuons");
 
       PromptFinalState taus(eta_full && Cuts::abspid == PID::TAU);
       declare(taus, "taus");
 
       VetoedFinalState vfs(fs);
-      InvisibleFinalState prompt_invis(true, true); // require promptness & allow from prompt tau decays
+      InvisibleFinalState prompt_invis(OnlyPrompt::YES, TauDecaysAs::PROMPT);
       vfs.addVetoOnThisFinalState(dressedelectrons);
       vfs.addVetoOnThisFinalState(dressedmuons);
       vfs.addVetoOnThisFinalState(prompt_invis);
-      FastJets jets(vfs, FastJets::ANTIKT, 0.4);
+      FastJets jets(vfs, JetAlg::ANTIKT, 0.4);
       declare(jets, "jets");
 
 
@@ -135,8 +135,8 @@ namespace Rivet {
 
     void analyze(const Event& event) {
 
-      vector<DressedLepton> elecs = apply<DressedLeptons>(event, "dressedelectrons").dressedLeptons();
-      vector<DressedLepton> muons = apply<DressedLeptons>(event, "dressedmuons").dressedLeptons();
+      DressedLeptons elecs = apply<LeptonFinder>(event, "dressedelectrons").dressedLeptons();
+      DressedLeptons muons = apply<LeptonFinder>(event, "dressedmuons").dressedLeptons();
       Particles taus = apply<PromptFinalState>(event, "taus").particlesByPt(Cuts::pT > 25*GeV && Cuts::abseta < 2.5);
       Jets jets = apply<FastJets>(event, "jets").jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta < 2.5);
 
@@ -158,7 +158,7 @@ namespace Rivet {
       if (taus.size())  vetoEvent; //No taus
 
       //At least 6 jets with pt > 55 GeV
-      if (filter_select(jets, Cuts::pT > 55*GeV).size() < 6)  vetoEvent;
+      if (select(jets, Cuts::pT > 55*GeV).size() < 6)  vetoEvent;
 
       //Exactly 2 bjets
       if ( bjets.size() != 2) vetoEvent;
@@ -398,64 +398,51 @@ namespace Rivet {
       _h["DR_e3e1_norm"]->fill(DR_e3e1);
 
 
-      _h_multi["t1_pt_jet_n_multi"].fill(jet_multiplicity_2D, t1.pt()/GeV);
-      _h_multi["t2_pt_jet_n_multi"].fill(jet_multiplicity_2D, t2.pt()/GeV);
-      _h_multi["tt_pt_jet_n_multi"].fill(jet_multiplicity_2D, pttbar.pt()/GeV);
-      _h_multi["absPout_jet_n_multi"].fill(jet_multiplicity_2D, absPout);
-      _h_multi["DeltaPhi_jet_n_multi"].fill(jet_multiplicity_2D, DPhi);
-      _h_multi["absPcross_jet_n_multi"].fill(jet_multiplicity_2D, absPcross);
-      _h_multi["t2_pt_m_multi"].fill(pttbar.mass()/GeV, t2.pt()/GeV);
-      _h_multi["tt_pt_m_multi"].fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
-      _h_multi["abs_tt_y_m_multi"].fill(pttbar.mass()/GeV, pttbar.absrap());
-      _h_multi["t1_pt_t2_pt_multi"].fill(t2.pt()/GeV, t1.pt()/GeV);
-      _h_multi["t1_pt_m_multi_y0"].fill(pttbar.mass()/GeV, t1.pt()/GeV);
-      _h_multi["t1_pt_jet_n_multi_norm"].fill(jet_multiplicity_2D, t1.pt()/GeV);
-      _h_multi["t2_pt_jet_n_multi_norm"].fill(jet_multiplicity_2D, t2.pt()/GeV);
-      _h_multi["tt_pt_jet_n_multi_norm"].fill(jet_multiplicity_2D, pttbar.pt()/GeV);
-      _h_multi["absPout_jet_n_multi_norm"].fill(jet_multiplicity_2D, absPout);
-      _h_multi["DeltaPhi_jet_n_multi_norm"].fill(jet_multiplicity_2D, DPhi);
-      _h_multi["absPcross_jet_n_multi_norm"].fill(jet_multiplicity_2D, absPcross);
-      _h_multi["t2_pt_m_multi_norm"].fill(pttbar.mass()/GeV, t2.pt()/GeV);
-      _h_multi["tt_pt_m_multi_norm"].fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
-      _h_multi["abs_tt_y_m_multi_norm"].fill(pttbar.mass()/GeV, pttbar.absrap());
-      _h_multi["t1_pt_t2_pt_multi_norm"].fill(t2.pt()/GeV, t1.pt()/GeV);
-      _h_multi["t1_pt_m_multi_y0_norm"].fill(pttbar.mass()/GeV, t1.pt()/GeV);
+      _h_multi["t1_pt_jet_n_multi"]->fill(jet_multiplicity_2D, t1.pt()/GeV);
+      _h_multi["t2_pt_jet_n_multi"]->fill(jet_multiplicity_2D, t2.pt()/GeV);
+      _h_multi["tt_pt_jet_n_multi"]->fill(jet_multiplicity_2D, pttbar.pt()/GeV);
+      _h_multi["absPout_jet_n_multi"]->fill(jet_multiplicity_2D, absPout);
+      _h_multi["DeltaPhi_jet_n_multi"]->fill(jet_multiplicity_2D, DPhi);
+      _h_multi["absPcross_jet_n_multi"]->fill(jet_multiplicity_2D, absPcross);
+      _h_multi["t2_pt_m_multi"]->fill(pttbar.mass()/GeV, t2.pt()/GeV);
+      _h_multi["tt_pt_m_multi"]->fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
+      _h_multi["abs_tt_y_m_multi"]->fill(pttbar.mass()/GeV, pttbar.absrap());
+      _h_multi["t1_pt_t2_pt_multi"]->fill(t2.pt()/GeV, t1.pt()/GeV);
+      _h_multi["t1_pt_m_multi_y0"]->fill(pttbar.mass()/GeV, t1.pt()/GeV);
+      _h_multi["t1_pt_jet_n_multi_norm"]->fill(jet_multiplicity_2D, t1.pt()/GeV);
+      _h_multi["t2_pt_jet_n_multi_norm"]->fill(jet_multiplicity_2D, t2.pt()/GeV);
+      _h_multi["tt_pt_jet_n_multi_norm"]->fill(jet_multiplicity_2D, pttbar.pt()/GeV);
+      _h_multi["absPout_jet_n_multi_norm"]->fill(jet_multiplicity_2D, absPout);
+      _h_multi["DeltaPhi_jet_n_multi_norm"]->fill(jet_multiplicity_2D, DPhi);
+      _h_multi["absPcross_jet_n_multi_norm"]->fill(jet_multiplicity_2D, absPcross);
+      _h_multi["t2_pt_m_multi_norm"]->fill(pttbar.mass()/GeV, t2.pt()/GeV);
+      _h_multi["tt_pt_m_multi_norm"]->fill(pttbar.mass()/GeV, pttbar.pt()/GeV);
+      _h_multi["abs_tt_y_m_multi_norm"]->fill(pttbar.mass()/GeV, pttbar.absrap());
+      _h_multi["t1_pt_t2_pt_multi_norm"]->fill(t2.pt()/GeV, t1.pt()/GeV);
+      _h_multi["t1_pt_m_multi_y0_norm"]->fill(pttbar.mass()/GeV, t1.pt()/GeV);
     }
 
     void finalize() {
 
       // Normalize to cross-section
-      const double sf = crossSection() / sumOfWeights();
+      const double sf = crossSection()/picobarn / sumOfWeights();
       for (auto& hit : _h) {
         scale(hit.second, sf);
         if (hit.first.find("_norm") != string::npos)  normalize(hit.second, 1.0, false);
       }
       for (auto& hit : _h_multi) {
-        if (hit.first.find("_norm") != string::npos) {
-          for (Histo1DPtr& hist : hit.second.histos()) { scale(hist, sf); }
-          const double norm2D = integral2D(hit.second);
-          hit.second.scale(safediv(1.0, norm2D), this);
-        }
-        else {
-          hit.second.scale(sf, this);
-        }
+        scale(hit.second, sf);
+        if (hit.first.find("_norm") != string::npos)  normalizeGroup(hit.second, 1.0, false);
       }
+      divByGroupWidth(_h_multi);
     }
 
   private:
 
-    double integral2D(BinnedHistogram& h_multi) {
-      double total_integral = 0;
-      for  (Histo1DPtr& h : h_multi.histos()) {
-        total_integral += h->integral(false);
-      }
-      return total_integral;
-    }
-
-    void book2D(string name, std::vector<double>& doubleDiff_bins, size_t table){
-      for (size_t i = 0; i < doubleDiff_bins.size() - 1; ++i) {
-        string nbin = std::to_string(i);
-        { Histo1DPtr tmp; _h_multi[name].add(doubleDiff_bins[i], doubleDiff_bins[i+1], book(tmp, table+i, 1, 1)); }
+    void book2D(const string& name, std::vector<double>& doubleDiff_bins, size_t table) {
+      book(_h_multi[name], doubleDiff_bins);
+      for (auto& b : _h_multi[name]->bins()) {
+        book(b, table + b.index() - 1, 1, 1);
       }
     }
 
@@ -497,10 +484,9 @@ namespace Rivet {
 
     /// @name Objects that are used by the event selection decisions
     map<string, Histo1DPtr> _h;
-    map<string, BinnedHistogram> _h_multi;
+    map<string, Histo1DGroupPtr> _h_multi;
   };
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(ATLAS_2020_I1801434);
 
 }
