@@ -14,7 +14,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -26,46 +26,44 @@ namespace Rivet {
       book(_h_n, 1, 1, 1);
 
     }
-    
+
     void findChildren(const Particle & p,int & nCharged) {
       for( const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  if(PID::isCharged(child.pid())) ++nCharged;
-	}
-	else
-	  findChildren(child,nCharged);
+        if(child.children().empty()) {
+          if(PID::isCharged(child.pid())) ++nCharged;
+        }
+        else
+          findChildren(child,nCharged);
       }
     }
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       for (const Particle& p :  apply<FinalState>(event, "UFS").particles(Cuts::pid==441)) {
-	int nCharged(0);
-	findChildren(p,nCharged);
-	_h_n->fill(min(nCharged,8));
+        int nCharged(0);
+        findChildren(p,nCharged);
+        _h_n->fill(min(nCharged,8));
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      normalize(_h_n,2.);
+      normalize(_h_n);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    Histo1DPtr _h_n;
-    //@}
+    /// @{
+    BinnedHistoPtr<int> _h_n;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(BESIII_2019_I1724880);
 
-
 }
