@@ -14,7 +14,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -23,7 +23,15 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      book(_nproton, "TMP/proton");
+      book(_nproton, 1, 1, 1);
+      for (const string& en : _nproton.binning().edges<0>()) {
+        const double end = std::stod(en)*GeV;
+        if (isCompatibleWithSqrtS(end)) {
+          _ecms = en;
+          break;
+        }
+      }
+      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
     }
 
 
@@ -32,50 +40,30 @@ namespace Rivet {
       const FinalState& fs = apply<FinalState>(event, "FS");
       if(fs.particles().size()!=2) vetoEvent;
       for (const Particle& p :  fs.particles()) {
-	if(abs(p.pid())!=PID::PROTON) vetoEvent;
+        if(abs(p.pid())!=PID::PROTON) vetoEvent;
       }
-      _nproton->fill();
+      _nproton->fill(_ecms);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double sigma = _nproton->val();
-      double error = _nproton->err();
-      sigma *= crossSection()/ sumOfWeights() /picobarn;
-      error *= crossSection()/ sumOfWeights() /picobarn; 
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr  mult;
-      book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      scale(_nproton, crossSection()/ sumOfWeights() /picobarn);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    CounterPtr _nproton;
-    //@}
+    /// @{
+    BinnedHistoPtr<string> _nproton;
+    string _ecms;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(BESIII_2019_I1736235);
 
-
 }
