@@ -107,7 +107,7 @@ namespace Rivet {
       if(!matched) vetoEvent;
       // check the Lambda decay mode
       bool radiative[2]={false,false};
-      // identify Lambda decay
+      // identifyt Lambda decay
       Particle baryon1;
       if ( (Lambda.children()[0].pid()==PID::PROTON &&
 	    Lambda.children()[1].pid()==PID::PIMINUS ) ) {
@@ -197,22 +197,21 @@ namespace Rivet {
       double aPlus =-0.758;
       double factor = 45.*(3. +aPsi)/(11. + 5.*aPsi)/aPlus;
       // plots
-      for(unsigned int ix=0;ix<2;++ix) {
-	for(unsigned int iy=0;iy<2;++iy) {
-	  scale(_h_mu[ix][iy],10.*0.2/ *_n[ix]);
-	}
+      for (unsigned int ix=0;ix<2;++ix) {
+        for(unsigned int iy=0;iy<2;++iy) {
+          scale(_h_mu[ix][iy],10.*0.2/ *_n[ix]);
+        }
       }
       // alpha from the moments
-      for(unsigned int ix=0;ix<3;++ix) {
-	double value = _t[ix]->val()/_n[ix]->val();
-	double error = _t[ix]->err()/_n[ix]->val();
- 	value *= factor;
-	error *= abs(factor);
-	if(ix==1) value *=-1.;
-	Scatter2DPtr  alpha;
-	book(alpha,2,1,1+ix);
-	alpha->addPoint(0.5, value, make_pair(0.5,0.5),
-			make_pair(error,error) );
+      for (unsigned int ix=0;ix<3;++ix) {
+        double value = _t[ix]->val()/_n[ix]->val();
+        double error = _t[ix]->err()/_n[ix]->val();
+        value *= factor;
+        error *= abs(factor);
+        if(ix==1) value *=-1.;
+        Estimate0DPtr  alpha;
+        book(alpha,2,1,1+ix);
+        alpha->set(value, error);
       }
     }
 
