@@ -22,24 +22,25 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       // histograms
       book(_h_total,1,1,1);
-      book(_h_pT   ,2,1,1);
-      book(_h_y    ,3,1,1);
+      book(_h_pT,   2,1,1);
+      book(_h_y,    3,1,1);
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
+      if (_edges.empty()) _edges = _h_total->xEdges();
       // Final state of unstable particles to get particle spectra
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       // loop over onium states
-      for( const Particle & p : ufs.particles(Cuts::abspid==511)) {
-	// cuts on pT and rapidity
-	double y  = p.absrap();
-	double pT = p.perp();
-	if( pT<5. || y>2.4 ) continue;
-	_h_total->fill(1.);
-	_h_pT->fill(pT);
-	_h_y->fill(y);
+      for (const Particle& p : ufs.particles(Cuts::abspid==511)) {
+        // cuts on pT and rapidity
+        const double y  = p.absrap();
+        const double pT = p.perp();
+        if (pT<5. || y>2.4)  continue;
+        _h_total->fill(_edges[0]);
+        _h_pT->fill(pT);
+        _h_y->fill(y);
       }
     }
 
@@ -47,10 +48,10 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       double fact = 0.5*crossSection()/microbarn/sumOfWeights();
-      scale(_h_total,fact);
-      scale(_h_pT   ,fact);
+      scale(_h_total, fact);
+      scale(_h_pT, fact);
       // 0.5 due +/- y
-      scale(_h_y    ,0.5*fact);
+      scale(_h_y, 0.5*fact);
     }
 
     /// @}
@@ -58,7 +59,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_total,_h_pT,_h_y;
+    BinnedHistoPtr<string> _h_total;
+    Histo1DPtr _h_pT,_h_y;
+    vector<string> _edges;
     /// @}
 
 
