@@ -2,7 +2,7 @@
 #include "Rivet/Projections/FinalState.hh"
 #include "Rivet/Projections/FastJets.hh"
 #include "Rivet/Projections/PartonicTops.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/IdentifiedFinalState.hh"
 #include "Rivet/Projections/InvisibleFinalState.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
@@ -12,22 +12,22 @@
 
 namespace Rivet {
 
+
   /// ttbar dilepton differential cross-sections in pp collisions at 13 TeV
   class CMS_2018_I1703993 : public Analysis {  //
   public:
+
     RIVET_DEFAULT_ANALYSIS_CTOR(CMS_2018_I1703993);  //
 
     void init() {
       // Parton level top quarks dilepton e/mu channels only
-      const bool acceptTauDecays = false;
-      declare(PartonicTops(PartonicTops::DecayMode::E_MU, acceptTauDecays),
-              "PartonTops");  // Partonic top decaying to e or mu
+      declare(PartonicTops(TopDecay::E_MU, PromptEMuFromTau::NO), "PartonTops");  // Partonic top decaying to e or mu
 
       // Build particle level tops starting from FinalState
       const FinalState fs(Cuts::pT > 0. && Cuts::abseta < 6.);
 
       // Neutrinos
-      InvisibleFinalState neutrinos(true, true, true);
+      InvisibleFinalState neutrinos(OnlyPrompt::YES, TauDecaysAs::PROMPT, MuDecaysAs::PROMPT);
       declare(neutrinos, "Neutrinos");
 
       // Projection for electrons and muons
@@ -38,17 +38,17 @@ namespace Rivet {
       IdentifiedFinalState photons(fs);
       photons.acceptIdPair(PID::PHOTON);
 
-      PromptFinalState prompt_leptons(charged_leptons, false);
-      PromptFinalState prompt_photons(photons, true);
+      PromptFinalState prompt_leptons(charged_leptons, TauDecaysAs::NONPROMPT);
+      PromptFinalState prompt_photons(photons, TauDecaysAs::PROMPT);
 
-      DressedLeptons dressed_leptons(prompt_photons, prompt_leptons, 0.1, lepton_cut, /*useDecayPhotons*/ true);
-      declare(dressed_leptons, "DressedLeptons");
+      LeptonFinder dressed_leptons(prompt_leptons, prompt_photons, 0.1, lepton_cut);
+      declare(dressed_leptons, "LeptonFinder");
 
       // Projection for jets
       VetoedFinalState fs_jets(fs);
       fs_jets.addVetoOnThisFinalState(dressed_leptons);
       fs_jets.vetoNeutrinos();
-      declare(FastJets(fs_jets, FastJets::ANTIKT, 0.4), "ak4jets");
+      declare(FastJets(fs_jets, JetAlg::ANTIKT, 0.4), "ak4jets");
 
       // Book hists for particle level, normalized values
       book(_h["top_pt_norm"], "d07-x01-y01");       //  table 15, normalized values
@@ -205,25 +205,21 @@ namespace Rivet {
 
       //Particle-level analysis
       // Select leptons
-      const vector<DressedLepton>& dressedLeptons = apply<DressedLeptons>(event, "DressedLeptons").dressedLeptons();
-      if (dressedLeptons.size() != 2)
-        vetoEvent;
-      sortByPt(dressedLeptons);
+      const DressedLeptons& dressedLeptons = apply<LeptonFinder>(event, "LeptonFinder").dressedLeptons();
+      if (dressedLeptons.size() != 2) vetoEvent;
 
       const FourMomentum& lepton1 = dressedLeptons[0].momentum();
       const FourMomentum& lepton2 = dressedLeptons[1].momentum();
-      if ((lepton1 + lepton2).mass() < 20*GeV)
-        vetoEvent;
+      if ((lepton1 + lepton2).mass() < 20*GeV)  vetoEvent;
 
       // Select neutrinos
       const Particles neutrinos = apply<InvisibleFinalState>(event, "Neutrinos").particlesByPt();
-      if (neutrinos.size() < 2)
-        vetoEvent;
+      if (neutrinos.size() < 2)  vetoEvent;
 
       // Select bjets
       const FastJets& fjJets = apply<FastJets>(event, "ak4jets");
       const Jets jets = fjJets.jetsByPt(Cuts::abseta < 2.4 && Cuts::pT > 30 * GeV);
-      const Jets bJets = filter_select(jets, hasBTag());
+      const Jets bJets = select(jets, hasBTag());
 
       // There should at least two b jets.
       if (bJets.size() < 2)
