@@ -21,7 +21,7 @@ namespace Rivet {
       // projections
       declare(UnstableParticles(),"UFS");
       // histos
-      book(_h,1,1,1);
+      book(_h, 1,1,1);
     }
 
 
@@ -32,10 +32,11 @@ namespace Rivet {
       	// boost to rest frame
       	LorentzTransform cms_boost;
       	// loop over decay products
-      	for(const Particle & p2 : p.children()) {
-      	  if(p2.abspid()==511 || p2.abspid()==521)
-	    _h->fill(abs(p2.p3().z()/p2.p3().mod()));
-	}
+      	for (const Particle& p2 : p.children()) {
+      	  if (p2.abspid()==511 || p2.abspid()==521) {
+	          _h->fill(abs(p2.p3().z()/p2.p3().mod()));
+          }
+        }
       }
     }
 
