@@ -9,7 +9,7 @@ namespace Rivet {
     public:
 
     /// @name Constructors etc.
-    //@{
+    /// @{
 
     /// Constructor
     LHCB_2012_I1119400() : Analysis("LHCB_2012_I1119400"),
@@ -20,20 +20,20 @@ namespace Rivet {
       _eta_max(4.5)
     {   }
 
-    //@}
+    /// @}
 
 
     public:
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       fillMap(_partLftMap);
 
       int id_shift = 0;
-      if (isCompatibleWithSqrtS(7000)) id_shift = 1;
+      if (isCompatibleWithSqrtS(7000*GeV)) id_shift = 1;
       // define ratios if second pdgid in pair is -1, it means that is a antiparticle/particle ratio
 
       _ratiotype["pbarp"]         = make_pair(2212, -1);
@@ -150,7 +150,7 @@ namespace Rivet {
       }
     }
 
-    //@}
+    /// @}
 
 
     private:
@@ -226,9 +226,9 @@ namespace Rivet {
 
     // Define histograms
     // ratio
-    std::map<std::string, Scatter2DPtr > _h_ratio_lowpt;
-    std::map<std::string, Scatter2DPtr > _h_ratio_midpt;
-    std::map<std::string, Scatter2DPtr > _h_ratio_highpt;
+    std::map<std::string, Estimate1DPtr > _h_ratio_lowpt;
+    std::map<std::string, Estimate1DPtr > _h_ratio_midpt;
+    std::map<std::string, Estimate1DPtr > _h_ratio_highpt;
     // numerator
     std::map<std::string, Histo1DPtr > _h_num_lowpt;
     std::map<std::string, Histo1DPtr > _h_num_midpt;
@@ -269,7 +269,7 @@ namespace Rivet {
       m[2128] =  1.316424E-24;  m[2212] =  1.E+16;  m[2214] =  5.578069E-24;  m[2216] =  4.388081E-24;
       m[2218] =  2.269697E-24;  m[2222] =  4.539394E-24;  m[2224] =  5.578069E-24;  m[2226] =  1.994582E-24;
       m[2228] =  2.269697E-24;  m[3112] =  1.479E-10;  m[3114] =  1.670589E-23;  m[3116] =  5.485102E-24;
-      m[3118] =  3.656734E-24;  m[3122] =  2.631E-10;  m[3124] =  4.219309E-23;  m[3126] =  8.227653E-24;
+      m[3118] =  3.656734E-24;  m[3122] =  2.631E-10;  m[102134] =  4.219309E-23;  m[3126] =  8.227653E-24;
       m[3128] =  3.291061E-24;  m[3212] =  7.4E-20;  m[3214] =  1.828367E-23;  m[3216] =  5.485102E-24;
       m[3218] =  3.656734E-24;  m[3222] =  8.018E-11;  m[3224] =  1.838582E-23;  m[3226] =  5.485102E-24;
       m[3228] =  3.656734E-24;  m[3312] =  1.639E-10;  m[3314] =  6.648608E-23;  m[3322] =  2.9E-10;
@@ -296,7 +296,7 @@ namespace Rivet {
       m[13116] =  5.485102E-24;  m[13122] =  1.316424E-23;  m[13124] =  1.09702E-23;  m[13126] =  6.928549E-24;
       m[13212] =  6.582122E-24;  m[13214] =  1.09702E-23;  m[13216] =  5.485102E-24;  m[13222] =  6.582122E-24;
       m[13224] =  1.09702E-23;  m[13226] =  5.485102E-24;  m[13314] =  2.742551E-23;
-      m[13324] =  2.742551E-23;  m[14122] =  1.828367E-22;  m[20022] =  1.E+16;  m[20113] =  1.567172E-24;
+      m[13324] =  2.742551E-23;  m[102142] =  1.828367E-22;  m[20022] =  1.E+16;  m[20113] =  1.567172E-24;
       m[20213] =  1.567172E-24;  m[20223] =  2.708692E-23;  m[20313] =  3.782829E-24;
       m[20315] =  2.384827E-24;  m[20323] =  3.782829E-24;  m[20325] =  2.384827E-24;
       m[20333] =  1.198929E-23;  m[20413] =  2.63E-24;  m[20423] =  2.63E-24;  m[20433] =  6.5821E-22;
@@ -334,7 +334,7 @@ namespace Rivet {
 
   const int LHCB_2012_I1119400::_stablePDGIds[205] = {
     311, 543, 545, 551, 555, 557, 1103, 2101, 2103, 2203, 3101, 3103, 3201, 3203, 3303,
-    4101, 4103, 4124, 4201, 4203, 4301, 4303, 4312, 4314, 4322, 4324, 4334, 4403, 4414,
+    4101, 4103, 102144, 4201, 4203, 4301, 4303, 4312, 4314, 4322, 4324, 4334, 4403, 4414,
     4424, 4434, 4444, 5101, 5103, 5114, 5201, 5203, 5214, 5224, 5301, 5303, 5314, 5324,
     5334, 5401, 5403, 5412, 5414, 5422, 5424, 5432, 5434, 5444, 5503, 5514, 5524, 5534,
     5544, 5554, 10022, 10333, 10335, 10443, 10541, 10543, 10551, 10553, 10555, 11112,
@@ -351,7 +351,6 @@ namespace Rivet {
     9900024, 9900041, 9900042 };
 
 
-  // Plugin hook
   RIVET_DECLARE_PLUGIN(LHCB_2012_I1119400);
 
 }
