@@ -23,44 +23,33 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      book(_nneutron, "TMP/neutron");
+      book(_nneutron, 1, 1, 1);
 
+      for (const string& en : _nneutron.binning().edges<0>()) {
+        double end = std::stod(en)*MeV;
+        if(isCompatibleWithSqrtS(end)) {
+          _ecms = en;
+          break;
+        }
+      }
+      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::NEUTRON) vetoEvent;
+        if(abs(p.pid())!=PID::NEUTRON) vetoEvent;
       }
-      _nneutron->fill();
+      _nneutron->fill(_ecms);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double sigma = _nneutron->val();
-      double error = _nneutron->err();
-      sigma *= crossSection()/ sumOfWeights() /nanobarn;
-      error *= crossSection()/ sumOfWeights() /nanobarn;
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr mult;
-      book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/MeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      scale(_nneutron, crossSection()/ sumOfWeights() /nanobarn);
     }
 
     /// @}
@@ -68,7 +57,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    CounterPtr _nneutron;
+    BinnedHistoPtr<string> _nneutron;
+    string _ecms;
     /// @}
 
 
