@@ -5,7 +5,7 @@
 namespace Rivet {
 
 
-  /// @brief Add a short analysis description here
+  /// @brief e+e- -> KS0 K+- pi-+
   class DM1_1982_I176801 : public Analysis {
   public:
 
@@ -14,14 +14,14 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       // Initialise and register projections
       declare(FinalState(), "FS");
-      book(_nKKpi, "/TMP/nKKpi");
-      
+      book(_nKKpi, "/TMP/nKKpi", refData(1,1,1));
+
     }
 
 
@@ -39,47 +39,30 @@ namespace Rivet {
       if(nCount[310]==1 &&
 	 ((nCount[ 211]==1&&nCount[-321]==1)||
 	  (nCount[-211]==1&&nCount[ 321]==1)))
-	_nKKpi->fill();
+	_nKKpi->fill(sqrtS()/MeV);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double sigma = _nKKpi->val();
-      double error = _nKKpi->err();
-      sigma *= crossSection()/ sumOfWeights() /nanobarn;
-      error *= crossSection()/ sumOfWeights() /nanobarn; 
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr mult;
+      scale(_nKKpi, crossSection()/ sumOfWeights() /nanobarn);
+      Estimate1DPtr mult;
       book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/MeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      barchart(_nKKpi,mult);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    CounterPtr _nKKpi;
-    //@}
+    /// @{
+    Histo1DPtr _nKKpi;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(DM1_1982_I176801);
 
 
