@@ -35,9 +35,8 @@ namespace {
 namespace Rivet {
 
 
-  AnalysisHandler::AnalysisHandler(const string& runname)
-    : _runname(runname),
-      _ntrials(0.0),
+  AnalysisHandler::AnalysisHandler()
+    : _ntrials(0.0),
       _isEndOfFile(false),
       _userxs{NAN, NAN},
       _initialised(false),
@@ -176,7 +175,9 @@ namespace Rivet {
       try {
         // Allow projection registration in the init phase onwards
         a->_allowProjReg = true;
+        a->preInit();
         a->init();
+        a->postInit();
         a->setProjectionHandler(_projHandler);
         a->syncDeclQueue();
         //MSG_DEBUG("Checking consistency of analysis: " << a->name());
@@ -506,9 +507,13 @@ namespace Rivet {
 
     // Run the analyses
     for (const AnaHandle& a : analyses()) {
+      // Set the current event ptr
+      a->_currentevent = &event;
       MSG_TRACE("About to run analysis " << a->name());
       try {
+        a->preAnalyze(event);
         a->analyze(event);
+        a->postAnalyze(event);
       } catch (const Error& err) {
         throw Error(a->name() + "::analyze method error: " + err.what());
       } catch (const std::bad_cast &err) {
@@ -517,6 +522,8 @@ namespace Rivet {
         throw Error(message);
       }
       MSG_TRACE("Finished running analysis " << a->name());
+      // Unset the current event ptr
+      a->_currentevent = nullptr;
     }
 
   }
@@ -632,7 +639,10 @@ namespace Rivet {
     // update Ntrials heuristic calculation
     const double ntrials = _ntrials + safediv(_fileCounter.get()->persistent(defaultWeightIndex())->sumW(),
                                               _xs.get()->persistent(defaultWeightIndex())->val());
-    if (ntrials != 0.) {
+    if (notNaN(_userxs.first)) { // user provided a custom cross-section
+      setCrossSection(_userxs, true);
+    }
+    else if (ntrials != 0.) {
       const double nFiles = _xserr.get()->persistent(defaultWeightIndex())->numEntries() + 1.0;
       for (size_t iW = 0; iW < numWeights(); ++iW) {
         const double sumw  = _eventCounter.get()->persistent(iW)->sumW();
@@ -678,8 +688,10 @@ namespace Rivet {
           ao.get()->setActiveFinalWeightIdx(iW);
         }
         try {
-          MSG_TRACE("running " << a->name() << "::finalize() for weight " << iW << ".");
+          MSG_TRACE("Running " << a->name() << "::finalize() for weight " << iW << ".");
+          a->preFinalize();
           a->finalize();
+          a->postFinalize();
         } catch (const Error& err) {
           throw Error(a->name() + "::finalize method error: " + err.what());
         }
@@ -1158,7 +1170,9 @@ namespace Rivet {
       try {
         // Allow projection registration in the init phase onwards
         a->_allowProjReg = true;
+        a->preInit();
         a->init();
+        a->postInit();
         a->setProjectionHandler(_projHandler);
         a->syncDeclQueue();
       } catch (const Error& err) {
@@ -1277,7 +1291,9 @@ namespace Rivet {
       try {
         // Allow projection registration in the init phase onwards
         a->_allowProjReg = true;
+        a->preInit();
         a->init();
+        a->postInit();
         a->setProjectionHandler(_projHandler);
         a->syncDeclQueue();
       } catch (const Error& err) {
@@ -1579,11 +1595,6 @@ namespace Rivet {
   }
 
 
-  string AnalysisHandler::runName() const {
-    return _runname;
-  }
-
-
   std::vector<std::string> AnalysisHandler::analysisNames() const {
     std::vector<std::string> rtn;
     for (const AnaHandle& a : analyses()) {
